pub fn with_floats<T>(mode: WireFloats, f: impl FnOnce() -> T) -> TExpand description
Encode float arrays under mode for the duration of f. Scoped — never leaks.
pub fn with_floats<T>(mode: WireFloats, f: impl FnOnce() -> T) -> TEncode float arrays under mode for the duration of f. Scoped — never leaks.