pub fn with_numerics<T>(n: WireNumerics, f: impl FnOnce() -> T) -> TExpand description
Encode integer arrays under n for the duration of f. Scoped — never leaks.
pub fn with_numerics<T>(n: WireNumerics, f: impl FnOnce() -> T) -> TEncode integer arrays under n for the duration of f. Scoped — never leaks.